Class Hierarchy (Selenium RC Server (Coreless) 1.0.1 API)
Date: 2009-06-09

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV NEXT | FRAMES NO FRAMES

## Hierarchy For All Packages

Package Hierarchies:
  cybervillains.ca, org.openqa.selenium.server, org.openqa.selenium.server.ant, org.openqa.selenium.server.browserlaunchers, org.openqa.selenium.server.browserlaunchers.locators, org.openqa.selenium.server.cli, org.openqa.selenium.server.commands, org.openqa.selenium.server.htmlrunner, org.openqa.selenium.server.log, org.openqa.selenium.server.testgenerator

## Class Hierarchy

- java.lang.Object
  - org.openqa.selenium.server.browserlaunchers.AbstractBrowserLauncher (implements org.openqa.selenium.server.browserlaunchers.BrowserLauncher)
    - org.openqa.selenium.server.browserlaunchers.DestroyableRuntimeExecutingBrowserLauncher
    - org.openqa.selenium.server.browserlaunchers.FirefoxChromeLauncher
      - org.openqa.selenium.server.browserlaunchers.Firefox2Launcher
      - org.openqa.selenium.server.browserlaunchers.Firefox3Launcher
    - org.openqa.selenium.server.browserlaunchers.FirefoxCustomProfileLauncher
      - org.openqa.selenium.server.browserlaunchers.ProxyInjectionFirefoxCustomProfileLauncher
    - org.openqa.selenium.server.browserlaunchers.GoogleChromeLauncher
    - org.openqa.selenium.server.browserlaunchers.InternetExplorerCustomProxyLauncher
      - org.openqa.selenium.server.browserlaunchers.ProxyInjectionInternetExplorerCustomProxyLauncher
    - org.openqa.selenium.server.browserlaunchers.KonquerorLauncher
    - org.openqa.selenium.server.browserlaunchers.OperaCustomProfileLauncher
    - org.openqa.selenium.server.browserlaunchers.SafariCustomProfileLauncher
      - org.openqa.selenium.server.browserlaunchers.ProxyInjectionSafariCustomProfileLauncher
      - org.openqa.selenium.server.browserlaunchers.SafariFileBasedLauncher
  - org.mortbay.http.handler.AbstractHttpHandler (implements org.mortbay.http.HttpHandler)
    - org.openqa.selenium.server.ProxyHandler
    - org.mortbay.http.handler.ResourceHandler
      - org.openqa.selenium.server.SeleniumDriverResourceHandler
      - org.openqa.selenium.server.htmlrunner.SingleTestSuiteResourceHandler
      - org.openqa.selenium.server.StaticContentHandler
  - org.openqa.selenium.server.log.AntJettyLoggerBuildListener (implements org.apache.tools.ant.BuildListener)
  - org.openqa.selenium.server.ApplicationRegistry
  - org.openqa.selenium.server.BrowserConfigurationOptions
  - org.openqa.selenium.server.browserlaunchers.BrowserInstallation
  - org.openqa.selenium.server.browserlaunchers.BrowserInstallationCache
  - org.openqa.selenium.server.browserlaunchers.BrowserLauncherFactory
  - org.openqa.selenium.server.BrowserResponseSequencer
  - org.openqa.selenium.server.BrowserSessionFactory
  - org.openqa.selenium.server.BrowserSessionFactory.BrowserSessionInfo
  - org.openqa.selenium.server.browserlaunchers.BrowserStringParser
  - org.openqa.selenium.server.browserlaunchers.BrowserStringParser.Result
  - org.openqa.selenium.server.CachedContentTestHandler (implements org.mortbay.http.HttpHandler)
  - org.openqa.selenium.server.commands.CaptureNetworkTrafficCommand.Entry
  - org.openqa.selenium.server.commands.CaptureNetworkTrafficCommand.Header
  - org.openqa.selenium.server.commands.CaptureScreenshotToStringCommand
  - cybervillains.ca.CertificateCreator
  - org.openqa.selenium.server.ClasspathResourceLocator (implements org.openqa.selenium.server.ResourceLocator)
  - org.openqa.selenium.server.commands.Command
    - org.openqa.selenium.server.commands.AddCustomRequestHeaderCommand
    - org.openqa.selenium.server.commands.CaptureEntirePageScreenshotToStringCommand
    - org.openqa.selenium.server.commands.CaptureNetworkTrafficCommand
    - org.openqa.selenium.server.commands.CaptureScreenshotCommand
    - org.openqa.selenium.server.commands.RetrieveLastRemoteControlLogsCommand
    - org.openqa.selenium.server.commands.SeleniumCoreCommand
  - org.openqa.selenium.server.CommandHolder
  - org.openqa.selenium.server.CommandQueue
  - org.openqa.selenium.server.CommandResultHolder
  - org.openqa.selenium.server.DefaultRemoteCommand (implements org.openqa.selenium.server.RemoteCommand)
  - org.apache.tools.ant.taskdefs.Execute
    - org.openqa.selenium.server.browserlaunchers.AsyncExecute
  - org.openqa.selenium.server.browserlaunchers.locators.Firefox2or3Locator (implements org.openqa.selenium.server.browserlaunchers.locators.BrowserLocator)
  - org.openqa.selenium.server.browserlaunchers.FirefoxChromeLauncher.ChromeUrlConvert
  - org.openqa.selenium.server.browserlaunchers.FirefoxLauncher (implements org.openqa.selenium.server.browserlaunchers.BrowserLauncher)
  - java.util.logging.Formatter
    - org.openqa.selenium.server.log.TerseFormatter
  - org.openqa.selenium.server.FrameAddress
  - org.openqa.selenium.server.FrameGroupCommandQueueSet
  - org.openqa.selenium.server.FsResourceLocator (implements org.openqa.selenium.server.ResourceLocator)
  - java.util.logging.Handler
    - org.openqa.selenium.server.log.ShortTermMemoryHandler
    - java.util.logging.StreamHandler
      - org.openqa.selenium.server.log.StdOutHandler
  - org.openqa.selenium.server.browserlaunchers.HTABrowserLauncher (implements org.openqa.selenium.server.browserlaunchers.BrowserLauncher)
  - org.openqa.selenium.server.HtmlIdentifier
  - org.openqa.selenium.server.htmlrunner.HTMLLauncher (implements org.openqa.selenium.server.htmlrunner.HTMLResultsListener)
  - org.openqa.selenium.server.htmlrunner.HTMLSuiteResult
  - org.openqa.selenium.server.htmlrunner.HTMLTestResults
  - org.openqa.selenium.server.InjectionHelper
  - org.openqa.selenium.server.browserlaunchers.InternetExplorerLauncher (implements org.openqa.selenium.server.browserlaunchers.BrowserLauncher)
  - org.openqa.selenium.server.IOHelper
  - cybervillains.ca.KeyStoreManager
  - org.openqa.selenium.server.browserlaunchers.LauncherUtils
  - org.openqa.selenium.server.log.LoggingManager
  - org.openqa.selenium.server.browserlaunchers.MacProxyManager
  - org.openqa.selenium.server.log.MaxLevelFilter (implements java.util.logging.Filter)
  - org.openqa.selenium.server.browserlaunchers.MockBrowserLauncher (implements org.openqa.selenium.server.browserlaunchers.BrowserLauncher, java.lang.Runnable)
  - org.openqa.selenium.server.ModifiedIO
  - org.apache.tools.ant.ProjectComponent (implements java.lang.Cloneable)
    - org.apache.tools.ant.Task
      - org.openqa.selenium.server.ant.SeleneseAntTask
  - org.openqa.selenium.server.RemoteControlConfiguration
  - org.openqa.selenium.server.cli.RemoteControlLauncher
  - org.mortbay.util.Resource (implements java.io.Serializable)
    - org.openqa.selenium.server.ClassPathResource
    - org.mortbay.util.URLResource
      - org.openqa.selenium.server.FutureFileResource
  - org.openqa.selenium.server.browserlaunchers.ResourceExtractor
  - org.openqa.selenium.server.RobotRetriever
  - org.openqa.selenium.server.browserlaunchers.SafariLauncher (implements org.openqa.selenium.server.browserlaunchers.BrowserLauncher)
  - org.openqa.selenium.server.htmlrunner.SeleniumHTMLRunnerResultsHandler (implements org.mortbay.http.HttpHandler)
  - org.openqa.selenium.server.SeleniumServer
  - org.openqa.selenium.server.browserlaunchers.locators.SingleBrowserLocator (implements org.openqa.selenium.server.browserlaunchers.locators.BrowserLocator)
    - org.openqa.selenium.server.browserlaunchers.locators.FirefoxLocator
      - org.openqa.selenium.server.browserlaunchers.locators.Firefox2Locator
      - org.openqa.selenium.server.browserlaunchers.locators.Firefox3Locator
    - org.openqa.selenium.server.browserlaunchers.locators.GoogleChromeLocator
    - org.openqa.selenium.server.browserlaunchers.locators.InternetExplorerLocator
    - org.openqa.selenium.server.browserlaunchers.locators.SafariLocator
  - org.openqa.selenium.server.SingleEntryAsyncQueue<T>
  - org.openqa.selenium.server.browserlaunchers.SystemUtils
  - java.lang.Throwable (implements java.io.Serializable)
    - java.lang.Exception
      - org.openqa.selenium.server.browserlaunchers.FirefoxChromeLauncher.FileLockRemainedException
      - org.openqa.selenium.server.browserlaunchers.FirefoxCustomProfileLauncher.FileLockRemainedException
      - org.openqa.selenium.server.RemoteCommandException
        - org.openqa.selenium.server.WindowClosedException
      - java.lang.RuntimeException
        - org.openqa.selenium.server.browserlaunchers.AsyncExecute.ProcessStillAliveException
        - org.openqa.selenium.server.browserlaunchers.InvalidBrowserExecutableException
        - org.openqa.selenium.server.SeleniumCommandTimedOutException
  - cybervillains.ca.ThumbprintUtil
  - java.util.TimerTask (implements java.lang.Runnable)
    - org.openqa.selenium.server.BrowserSessionFactory.CleanupTask
  - org.openqa.selenium.server.TrustEverythingSSLTrustManager (implements javax.net.ssl.X509TrustManager)
  - org.openqa.selenium.server.browserlaunchers.UnixUtils
  - org.openqa.selenium.server.browserlaunchers.WindowsProxyManager
  - org.openqa.selenium.server.browserlaunchers.WindowsUtils
  - org.openqa.selenium.server.testgenerator.XlateHtmlSeleneseToJava

## Interface Hierarchy

- org.openqa.selenium.server.browserlaunchers.BrowserLauncher
- org.openqa.selenium.server.browserlaunchers.locators.BrowserLocator
- org.openqa.selenium.server.browserlaunchers.CommandQueueAware
- org.openqa.selenium.server.htmlrunner.HTMLResultsListener
- org.openqa.selenium.server.RemoteCommand
- org.openqa.selenium.server.ResourceLocator

## Enum Hierarchy

- java.lang.Object
  - java.lang.Enum<E> (implements java.lang.Comparable<T>, java.io.Serializable)
    - org.openqa.selenium.server.SpecialCommand
    - org.openqa.selenium.server.browserlaunchers.LauncherUtils.ProxySetting

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV NEXT | FRAMES NO FRAMES

Copyright © 2009. All Rights Reserved.